You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@commons.apache.org by sa...@apache.org on 2006/03/23 06:34:57 UTC

svn commit: r388047 - /jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/

Author: sandymac
Date: Wed Mar 22 21:34:56 2006
New Revision: 388047

URL: http://svn.apache.org/viewcvs?rev=388047&view=rev
Log:
JavaDoc clean ups and speeling corrections. :-)

Modified:
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/BorrowType.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeKeyedObjectPoolFactory.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeObjectPoolFactory.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/ExhaustionBehavior.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/IdleEvictorLender.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/InvalidEvictorLender.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/LimitBehavior.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/TrackingType.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/WaitLimitManager.java
    jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/package.html

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/BorrowType.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/BorrowType.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/BorrowType.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/BorrowType.java Wed Mar 22 21:34:56 2006
@@ -60,7 +60,7 @@
     public static final BorrowType SOFT_LIFO = new BorrowType("SOFT_LIFO");
 
     /**
-     * Never returns an object from the pool nor returns one to the pool. This basicly turns the pool into a factory,
+     * Never returns an object from the pool nor returns one to the pool. This basically turns the pool into a factory,
      * it may have some utility if used with {@link CompositeObjectPoolFactory#setMaxActive(int) maxActive}.
      * This is not compatible with {@link ExhaustionBehavior#FAIL}.
      */

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeKeyedObjectPoolFactory.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeKeyedObjectPoolFactory.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeKeyedObjectPoolFactory.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeKeyedObjectPoolFactory.java Wed Mar 22 21:34:56 2006
@@ -26,12 +26,11 @@
 import java.io.Serializable;
 
 /**
- * {@link KeyedObjectPoolFactory} that builds a custom {@link KeyedObjectPool} via composition of custom
- * {@link ObjectPool}s.
+ * <code>KeyedObjectPoolFactory</code> that builds an optimized custom <code>KeyedObjectPool</code> with the requested feature set.
  *
- * <p>Note: Currently the default values and behavior is effectivly inherited from {@link CompositeObjectPoolFactory},
- * review it if you are uncertian about the behavior of this factory. Future verions of this factory may not inherit
- * behavior from the {@link CompositeObjectPoolFactory}.
+ * <p>Note: Currently the default values and behavior is effectively inherited from {@link CompositeObjectPoolFactory},
+ * review it if you are uncertain about the behavior of this factory. Future versions of this factory may not inherit
+ * behavior from the <code>CompositeObjectPoolFactory</code>.
  * </p>
  *
  * @see CompositeObjectPoolFactory
@@ -53,9 +52,9 @@
     private final CompositeObjectPoolFactory factory;
 
     /**
-     * Create a new keyed object pool factory witht he specific keyed object factory.
+     * Create a new keyed object pool factory with the specified keyed poolable object factory.
      *
-     * @param factory the keyed object factory for this pool, must not be null.
+     * @param factory the factory for created pools, must not be <code>null</code>.
      * @throws IllegalArgumentException if <code>factory</code> is <code>null</code>.
      * @see #setKeyedFactory(KeyedPoolableObjectFactory)
      */
@@ -67,11 +66,11 @@
     }
 
     /**
-     * Create a new keyed object pool factory with the specific object factory. This is a convenience constructor for
-     * when you have a {@link PoolableObjectFactory} but want a {@link KeyedObjectPool} and the
-     * {@link PoolableObjectFactory object factory} doesn't care about the key.
+     * Create a new keyed object pool factory with the specified poolable object factory. This is a convenience
+     * constructor for when you have a {@link PoolableObjectFactory} but want a {@link KeyedObjectPool} and the
+     * poolable object factory doesn't care about the key.
      *
-     * @param factory the object factory for this pool, must not be null.
+     * @param factory the poolable object factory for created pools, must not be <code>null</code>.
      * @throws IllegalArgumentException if <code>factory</code> is <code>null</code>.
      * @see #setFactory(PoolableObjectFactory)
      */
@@ -83,10 +82,10 @@
     }
 
     /**
-     * Create a new keyed object pool factory that uses a {@link CompositeObjectPoolFactory} to create
-     * {@link ObjectPool}s for each key.
+     * Create a new keyed object pool factory that uses a <code>CompositeObjectPoolFactory</code> to create object pools
+     * for each key.
      *
-     * @param factory the object factory to back this keyed object factory.
+     * @param factory the object pool factory to back this keyed object pool factory.
      * @throws IllegalArgumentException if <code>factory</code> is <code>null</code>.
      */
     public CompositeKeyedObjectPoolFactory(final CompositeObjectPoolFactory factory) throws IllegalArgumentException {
@@ -104,7 +103,7 @@
     }
 
     /**
-     * Create a new {@link KeyedObjectPool}.
+     * Create a new <code>KeyedObjectPool</code>.
      *
      * @return a new {@link KeyedObjectPool}
      */
@@ -121,12 +120,12 @@
     }
 
     /**
-     * Create a new {@link KeyedObjectPool} that uses an {@link ObjectPoolFactory} to create an internal
-     * {@link ObjectPool} to back each key. Use of this method is generally discouraged but it could be used to do some
-     * generally funky and intersting things.
+     * Create a new <code>KeyedObjectPool</code> that uses an <code>ObjectPoolFactory</code> to create an internal
+     * <code>ObjectPool</code> to back each key. Use of this method is generally discouraged but it could be used to do
+     * some generally funky and interesting things.
      *
-     * <p><b>There are no guarentees the {@link KeyedObjectPool} returned by this method will behave in previously
-     * guarenteed way. Use at your own risk.</b></p>
+     * <p><b>There are no guarantees the <code>KeyedObjectPool</code> returned by this method will behave in previously
+     * guaranteed way. Use at your own risk.</b></p>
      *
      * @param factory the object pool factory that creates object pools to back each key.
      * @return a keyed object pool that uses an object pool factory to create object pools to back each key.
@@ -217,9 +216,9 @@
     }
 
     /**
-     * Behavior of the pool when all idle objects have been exhasted.
+     * Behavior of the pool when all idle objects have been exhausted.
      *
-     * @return behavior of the pool when all idle objects have been exhasted.
+     * @return behavior of the pool when all idle objects have been exhausted.
      */
     public ExhaustionBehavior getExhaustionBehavior() {
         return factory.getExhaustionBehavior();
@@ -239,7 +238,7 @@
      * Maximum number of idle objects in the pool for each key.
      * A negative value means unlimited.
      * Zero means the pool will behave like a factory.
-     * A positve value limits the number of idle objects.
+     * A positive value limits the number of idle objects.
      *
      * @return a non-negative value is the maximum number of idle objects in the pool for each key, else unlimited.
      */
@@ -251,7 +250,7 @@
      * Set the maximum number of idle objects in the pool for each key.
      * A negative value means unlimited.
      * Zero means the pool will behave like a factory.
-     * A positve value limits the number of idle objects.
+     * A positive value limits the number of idle objects.
      *
      * @param maxIdle a non-negative value is the maximum number of idle objects in the pool for each key, else unlimited.
      */
@@ -301,7 +300,7 @@
     }
 
     /**
-     * Wait time in milli-seconds for an object to become available to the pool when the {@link LimitBehavior#WAIT WAIT}
+     * Wait time in milliseconds for an object to become available to the pool when the {@link LimitBehavior#WAIT WAIT}
      * {@link #setLimitBehavior(LimitBehavior) limit behavior} is used.
      *
      * @return the wait time for an object to become available to the pool.
@@ -312,11 +311,11 @@
     }
 
     /**
-     * Set the wait time in milli-seconds for an object to become available to the pool when it was exhausted.
+     * Set the wait time in milliseconds for an object to become available to the pool when it was exhausted.
      * This has no effect unless the {@link #setLimitBehavior(LimitBehavior) limit behavior}
      * is set to {@link LimitBehavior#WAIT}.
      *
-     * @param maxWaitMillis the milli-seconds to wait for an available object in the pool or &lt;= 0 for no limit.
+     * @param maxWaitMillis the milliseconds to wait for an available object in the pool or &lt;= 0 for no limit.
      * @see #setLimitBehavior(LimitBehavior)
      */
     public void setMaxWaitMillis(final int maxWaitMillis) {
@@ -364,7 +363,7 @@
      * Idle timeout for idle objects to be evicted.
      * A non-positive value means do not evict objects just because they are idle.
      *
-     * @return if positive the time in milli-seconds to evict idle objects.
+     * @return if positive the time in milliseconds to evict idle objects.
      */
     public long getEvictIdleMillis() {
         return factory.getEvictIdleMillis();
@@ -374,7 +373,7 @@
      * Set the idle timeout for idle objects to be evicted.
      * A non-positive value means do not evict objects just because they are idle.
      *
-     * @param evictIdleMillis if positive the time in milli-seconds to evict idle objects.
+     * @param evictIdleMillis if positive the time in milliseconds to evict idle objects.
      */
     public void setEvictIdleMillis(final long evictIdleMillis) {
         factory.setEvictIdleMillis(evictIdleMillis);
@@ -384,7 +383,7 @@
      * Frequency idle objects should be checked to be still valid.
      * A non-positive value means do not evict objects just because they fail to validate.
      *
-     * @return if positive the frequency in milli-seconds to check that idle objects are still valid.
+     * @return if positive the frequency in milliseconds to check that idle objects are still valid.
      */
     public long getEvictInvalidFrequencyMillis() {
         return factory.getEvictInvalidFrequencyMillis();
@@ -394,7 +393,7 @@
      * Set the frequency idle objects should be checked to be still valid.
      * A non-positive value means do not evict objects just because they fail to validate.
      *
-     * @param evictInvalidFrequencyMillis if positive the frequency in milli-seconds to check that
+     * @param evictInvalidFrequencyMillis if positive the frequency in milliseconds to check that
      * idle objects are still valid.
      */
     public void setEvictInvalidFrequencyMillis(final long evictInvalidFrequencyMillis) {
@@ -418,7 +417,7 @@
         if (!getClass().equals(CompositeKeyedObjectPoolFactory.class)) {
             throw new CloneNotSupportedException("Subclasses must not call super.clone()");
         }
-        // factory will be cloned in the constuctor
+        // factory will be cloned in the constructor
         return new CompositeKeyedObjectPoolFactory(factory);
     }
 }

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeObjectPoolFactory.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeObjectPoolFactory.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeObjectPoolFactory.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/CompositeObjectPoolFactory.java Wed Mar 22 21:34:56 2006
@@ -27,7 +27,7 @@
 import java.util.List;
 
 /**
- * {@link ObjectPoolFactory} that builds a custom {@link ObjectPool} via composition.
+ * <code>ObjectPoolFactory</code> that builds an optimized custom <code>ObjectPool</code> with the requested feature set.
  *
  * <p>Default values for a newly created factory:
  * <ul>
@@ -36,11 +36,11 @@
  *  <li>{@link #setExhaustionBehavior(ExhaustionBehavior) exhaustionBehavior}:
  *      {@link ExhaustionBehavior#GROW GROW}</li>
  *  <li>{@link #setMaxIdle(int) maxIdle}: a negative value (unlimited)</li>
- *  <li>{@link #setMaxActive(int) maxActive}: a non-positve value (unlimited)</li>
+ *  <li>{@link #setMaxActive(int) maxActive}: a non-positive value (unlimited)</li>
  *  <li>{@link #setLimitBehavior(LimitBehavior) limitBehavior}:
  *      {@link LimitBehavior#FAIL FAIL}
  *      (has no effect unless {@link #setMaxActive(int) maxActive} is positive)</li>
- *  <li>{@link #setMaxWaitMillis(int) maxWaitMillis}: a non-positve value (wait forever)
+ *  <li>{@link #setMaxWaitMillis(int) maxWaitMillis}: a non-positive value (wait forever)
  *      (has no effect unless {@link #setLimitBehavior(LimitBehavior) limitBehavior} is
  *      {@link LimitBehavior#WAIT WAIT})</li>
  *  <li>{@link #setTrackerType(TrackingType) trackingType}:
@@ -86,7 +86,7 @@
  * pool.addObject(); pool.addObject(); pool.addObject();
  * </pre>
  *
- * <p>To create a fifo {@link ObjectPool} that doesn't prevent idle objects from being garabage collected, detects when
+ * <p>To create a fifo {@link ObjectPool} that doesn't prevent idle objects from being garbage collected, detects when
  * borrowed objects are not returned to the pool and prints a stack trace from where they were borrowed.
  * </p>
  * <pre>
@@ -126,7 +126,7 @@
  *      borrowed from the serialized {@link ObjectPool} must not be returned to the deserialized {@link ObjectPool}.
  *      All other behavior and settings of the {@link ObjectPool} will be maintained.</li>
  *  <li>{@link ObjectPool}s created by this factory are {@link Cloneable}. Cloned instances do not retain the idle
- *      objects of the original instance and any active objects borrowed from the originial must not be returned to the
+ *      objects of the original instance and any active objects borrowed from the original must not be returned to the
  *      new clone.</li>
  * </ul>
  * </p>
@@ -175,12 +175,12 @@
      * Maximum number of idle objects in the pool.
      * A negative value means unlimited.
      * Zero means the pool will behave like a factory.
-     * A positve value limits the number of idle objects.
+     * A positive value limits the number of idle objects.
      */
     private int maxIdle = -1;
 
     /**
-     * Maximum nuber of active objects from the pool. A non-positive value means unlimited.
+     * Maximum number of active objects from the pool. A non-positive value means unlimited.
      *
      * @see ActiveLimitManager
      */
@@ -192,19 +192,19 @@
     private LimitBehavior limitBehavior = LimitBehavior.FAIL;
 
     /**
-     * Configured max wait time for an available object. Non-positve means wait forever.
+     * Configured max wait time for an available object. Non-positive means wait forever.
      *
      * @see WaitLimitManager
      */
     private int maxWaitMillis = -1;
 
     /**
-     * Configued {@link Tracker} type.
+     * Configured {@link Tracker} type.
      */
     private TrackingType trackerType = TrackingType.SIMPLE;
 
     /**
-     * Should the object pool validate borrowed objects when they are reutrned.
+     * Should the object pool validate borrowed objects when they are returned.
      */
     private boolean validateOnReturn = false;
 
@@ -230,7 +230,7 @@
     }
 
     /**
-     * Create and return a new {@link ObjectPool}.
+     * Create and return a new <code>ObjectPool</code>.
      *
      * @return a new {@link ObjectPool}
      */
@@ -274,7 +274,7 @@
 
         } else {
             // For small list sizes the cost of shuffling the items in an array down one spot
-            // is cheaper than for LinkList to manage it's internal stuctures.
+            // is cheaper than for LinkedList to manage it's internal structures.
             // The threshold (10) was based on some benchmarks on some 1.4 and 1.5 JVMs was between 10 to 25
             if (0 <= config.maxIdle && config.maxIdle <= 10) {
                 list = new ArrayList(config.maxIdle);
@@ -465,9 +465,9 @@
     }
 
     /**
-     * Behavior of the pool when all idle objects have been exhasted.
+     * Behavior of the pool when all idle objects have been exhausted.
      *
-     * @return behavior of the pool when all idle objects have been exhasted.
+     * @return behavior of the pool when all idle objects have been exhausted.
      */
     public ExhaustionBehavior getExhaustionBehavior() {
         return exhaustionBehavior;
@@ -493,7 +493,7 @@
      * Maximum number of idle objects in the pool.
      * A negative value means unlimited.
      * Zero means the pool will behave like a factory.
-     * A positve value limits the number of idle objects.
+     * A positive value limits the number of idle objects.
      *
      * @return a non-negative value is the maximum number of idle objects in the pool, else unlimited.
      */
@@ -505,7 +505,7 @@
      * Set the maximum number of idle objects in the pool.
      * A negative value means unlimited.
      * Zero means the pool will behave like a factory.
-     * A positve value limits the number of idle objects.
+     * A positive value limits the number of idle objects.
      *
      * @param maxIdle a non-negative value is the maximum number of idle objects in the pool, else unlimited.
      */
@@ -565,22 +565,23 @@
     }
 
     /**
-     * Wait time in milli-seconds for an object to become available to the pool when the {@link LimitBehavior#WAIT WAIT}
-     * {@link #setLimitBehavior(LimitBehavior) limit behavior} is used.
+     * Wait time in milliseconds for an object to become available to the pool when the {@link LimitBehavior#WAIT WAIT}
+     * <code>LimitBehavior</code> is used.
      *
      * @return the wait time for an object to become available to the pool.
      * @see #getLimitBehavior()
+     * @see LimitBehavior#WAIT
      */
     public int getMaxWaitMillis() {
         return maxWaitMillis;
     }
 
     /**
-     * Set the wait time in milli-seconds for an object to become available to the pool when it was exhausted.
+     * Set the wait time in milliseconds for an object to become available to the pool when it was exhausted.
      * This has no effect unless the {@link #setLimitBehavior(LimitBehavior) limit behavior}
      * is set to {@link LimitBehavior#WAIT}.
      *
-     * @param maxWaitMillis the milli-seconds to wait for an available object in the pool or &lt;= 0 for no limit.
+     * @param maxWaitMillis the milliseconds to wait for an available object in the pool or &lt;= 0 for no limit.
      * @see #setLimitBehavior(LimitBehavior)
      */
     public void setMaxWaitMillis(final int maxWaitMillis) {
@@ -640,7 +641,7 @@
      * Idle timeout for idle objects to be evicted.
      * A non-positive value means do not evict objects just because they are idle.
      *
-     * @return if positive the time in milli-seconds to evict idle objects.
+     * @return if positive the time in milliseconds to evict idle objects.
      */
     public long getEvictIdleMillis() {
         synchronized (lock) {
@@ -652,7 +653,7 @@
      * Set the idle timeout for idle objects to be evicted.
      * A non-positive value means do not evict objects just because they are idle.
      *
-     * @param evictIdleMillis if positive the time in milli-seconds to evict idle objects.
+     * @param evictIdleMillis if positive the time in milliseconds to evict idle objects.
      */
     public void setEvictIdleMillis(final long evictIdleMillis) {
         synchronized (lock){
@@ -665,7 +666,7 @@
      * Frequency idle objects should be checked to be still valid.
      * A non-positive value means do not evict objects just because they fail to validate.
      *
-     * @return if positive the frequency in milli-seconds to check that idle objects are still valid.
+     * @return if positive the frequency in milliseconds to check that idle objects are still valid.
      */
     public long getEvictInvalidFrequencyMillis() {
         synchronized (lock) {
@@ -677,7 +678,7 @@
      * Set the frequency idle objects should be checked to be still valid.
      * A non-positive value means do not evict objects just because they fail to validate.
      *
-     * @param evictInvalidFrequencyMillis if positive the frequency in milli-seconds to check that
+     * @param evictInvalidFrequencyMillis if positive the frequency in milliseconds to check that
      * idle objects are still valid.
      */
     public void setEvictInvalidFrequencyMillis(final long evictInvalidFrequencyMillis) {
@@ -747,7 +748,7 @@
         private final long evictInvalidFrequencyMillis;
 
         /**
-         * Convenience constuctor. This <b>must</b> be called from a synchronized context to be thread-safe.
+         * Convenience constructor. This <b>must</b> be called from a synchronized context to be thread-safe.
          */
         FactoryConfig(final CompositeObjectPoolFactory copf) {
             this(copf.getFactory(), copf.getBorrowType(), copf.getExhaustionBehavior(), copf.getMaxIdle(),

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/ExhaustionBehavior.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/ExhaustionBehavior.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/IdleEvictorLender.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/IdleEvictorLender.java Wed Mar 22 21:34:56 2006
@@ -31,7 +31,7 @@
     private static final long serialVersionUID = 2422278988668384937L;
 
     /**
-     * Time, in milli-seconds, before the idle objects are evicted.
+     * Time, in milliseconds, before the idle objects are evicted.
      */
     private long idleTimeoutMillis = 60L * 60L * 1000L; // 60 minute
 
@@ -50,17 +50,17 @@
     }
 
     /**
-     * Get the time, in milli-seconds, before the idle objects are evicted.
-     * @return the time, in milli-seconds, before the idle objects are evicted.
+     * Get the time, in milliseconds, before the idle objects are evicted.
+     * @return the time, in milliseconds, before the idle objects are evicted.
      */
     public long getIdleTimeoutMillis() {
         return idleTimeoutMillis;
     }
 
     /**
-     * Set the time, in milli-seconds, before the idle objects are evicted.
+     * Set the time, in milliseconds, before the idle objects are evicted.
      *
-     * @param idleTimeoutMillis the time, in milli-seconds, before the idle objects are evicted.
+     * @param idleTimeoutMillis the time, in milliseconds, before the idle objects are evicted.
      */
     public void setIdleTimeoutMillis(final long idleTimeoutMillis) {
         this.idleTimeoutMillis = idleTimeoutMillis;

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/InvalidEvictorLender.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/InvalidEvictorLender.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/InvalidEvictorLender.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/InvalidEvictorLender.java Wed Mar 22 21:34:56 2006
@@ -34,7 +34,7 @@
     private static final long serialVersionUID = -3200445766813431919L;
 
     /**
-     * Time, in milli-seconds, between the checks that idle objects are still
+     * Time, in milliseconds, between the checks that idle objects are still
      * {@link PoolableObjectFactory#validateObject(Object) valid}.
      */
     private long validationFrequencyMillis = 10L * 60L * 1000L; // 10 minute
@@ -55,20 +55,20 @@
     }
 
     /**
-     * Get the time, in milli-seconds, between the checks that idle objects are still
+     * Get the time, in milliseconds, between the checks that idle objects are still
      * {@link PoolableObjectFactory#validateObject(Object) valid}.
      *
-     * @return time, in milli-seconds, between the checks that idle objects are still valid.
+     * @return time, in milliseconds, between the checks that idle objects are still valid.
      */
     public long getValidationFrequencyMillis() {
         return validationFrequencyMillis;
     }
 
     /**
-     * Set the time, in milli-seconds, between the checks that idle objects are still
+     * Set the time, in milliseconds, between the checks that idle objects are still
      * {@link PoolableObjectFactory#validateObject(Object) valid}.
      *
-     * @param validationFrequencyMillis time, in milli-seconds, between the checks that idle objects are still valid.
+     * @param validationFrequencyMillis time, in milliseconds, between the checks that idle objects are still valid.
      * @throws IllegalArgumentException if validationFrequencyMillis is negative
      */
     public void setValidationFrequencyMillis(final long validationFrequencyMillis) throws IllegalArgumentException {

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/LimitBehavior.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/LimitBehavior.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/TrackingType.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/TrackingType.java Wed Mar 22 21:34:56 2006
@@ -35,7 +35,7 @@
 
     /**
      * Do not track how objects are borrowed from the pool. While this is the fastest tracking type it is
-     * incompatable with pools that limit the number of objects in the pool.
+     * incompatible with pools that limit the number of objects in the pool.
      */
     public static final TrackingType NULL = new TrackingType("NULL");
 

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/WaitLimitManager.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/WaitLimitManager.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/WaitLimitManager.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/WaitLimitManager.java Wed Mar 22 21:34:56 2006
@@ -77,16 +77,16 @@
     }
 
     /**
-     * The max wait time in milli-seconds for a pooled object to become available.
+     * The max wait time in milliseconds for a pooled object to become available.
      *
-     * @return max wait time in milli-seconds for a pooled object to become available.
+     * @return max wait time in milliseconds for a pooled object to become available.
      */
     public long getMaxWaitMillis() {
         return maxWaitMillis;
     }
 
     /**
-     * Set the max wait time in milli-seconds for a pooled object to become available.
+     * Set the max wait time in milliseconds for a pooled object to become available.
      * A non-positve value means wait forever.
      *
      * @param maxWaitMillis max wait for an object to become available or &lt;= 0 for no limit.

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/package.html
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/package.html?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/package.html (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/package.html Wed Mar 22 21:34:56 2006
@@ -18,7 +18,8 @@
 <html>
 <body>
 <p>
-    Composite [Keyed] Object Pool implementation.
+    Object pooling implementation that uses composition to create a pool
+    with the desired feature set and optimal performance.
 </p>
 
 <h3>About</h3>



---------------------------------------------------------------------
To unsubscribe, e-mail: commons-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: commons-dev-help@jakarta.apache.org
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/ExhaustionBehavior.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/ExhaustionBehavior.java Wed Mar 22 21:34:56 2006
@@ -17,13 +17,14 @@
 package org.apache.commons.pool.composite;
 
 import org.apache.commons.pool.ObjectPool;
+import org.apache.commons.pool.PoolUtils;
 
 import java.io.ObjectStreamException;
 import java.io.Serializable;
 import java.util.NoSuchElementException;
 
 /**
- * Specifies the behavor of the pool when the pool is out of idle objects.
+ * Specifies the behavior of the pool when the pool is out of idle objects.
  *
  * @see CompositeObjectPoolFactory#setExhaustionBehavior(ExhaustionBehavior)
  * @see CompositeKeyedObjectPoolFactory#setExhaustionBehavior(ExhaustionBehavior)
@@ -41,8 +42,10 @@
     public static final ExhaustionBehavior GROW = new ExhaustionBehavior("GROW");
 
     /**
      * Throw a {@link NoSuchElementException} when all idle objects have been exhaused. Clients of the poll must
      * call {@link ObjectPool#addObject()} to prefill the pool.
+     * @see NoSuchElementException
+     * @see PoolUtils#prefill
      */
     public static final ExhaustionBehavior FAIL = new ExhaustionBehavior("FAIL");
 
@@ -41,8 +42,10 @@
 
     /**
-     * Throw a {@link NoSuchElementException} when all idle objects have been exhaused. Clients of the poll must
+     * Throw a <code>NoSuchElementException</code> when all idle objects have been exhausted. Clients of the pool must
      * call {@link ObjectPool#addObject()} to prefill the pool.

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/IdleEvictorLender.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/IdleEvictorLender.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================
--- jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/LimitBehavior.java (original)
+++ jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/LimitBehavior.java Wed Mar 22 21:34:56 2006
@@ -16,6 +16,9 @@
 
 package org.apache.commons.pool.composite;
 
+import org.apache.commons.pool.ObjectPool;
+import org.apache.commons.pool.KeyedObjectPool;
+
 import java.io.ObjectStreamException;
 import java.io.Serializable;
 import java.util.NoSuchElementException;
@@ -34,14 +37,20 @@
     private static final long serialVersionUID = -4325661345028907604L;
 
     /**
-     * When the number of active objects has been reached fail with a {@link NoSuchElementException} instead of
+     * When the number of active objects has been reached, fail with a <code>NoSuchElementException</code> instead of
      * returning a new object.
+     * @see NoSuchElementException
+     * @see ObjectPool#getNumActive
+     * @see KeyedObjectPool#getNumActive
      */
     public static final LimitBehavior FAIL = new LimitBehavior("FAIL");
 
     /**
      * When the number of active objects has been reached wait for the specified amount of time before failing with
      * a {@link NoSuchElementException}.
      */
     public static final LimitBehavior WAIT = new LimitBehavior("WAIT");
 
@@ -34,14 +37,20 @@
 
     /**
-     * When the number of active objects has been reached wait for the specified amount of time before failing with
-     * a {@link NoSuchElementException}.
+     * When the number of active objects has been reached, wait for the specified amount of time before failing with
+     * a <code>NoSuchElementException</code>.
+     * @see NoSuchElementException
+     * @see ObjectPool#getNumActive
+     * @see KeyedObjectPool#getNumActive
      */
     public static final LimitBehavior WAIT = new LimitBehavior("WAIT");

Modified: jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/TrackingType.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/pool/trunk/src/java/org/apache/commons/pool/composite/TrackingType.java?rev=388047&r1=388046&r2=388047&view=diff
==============================================================================